<template>
  <div class="app-container">
    <el-form
      :model="queryParams"
      ref="queryForm"
      size="small"
      :inline="true"
      v-show="showSearch"
      label-width="68px"
    >
      <el-form-item label=" 标签分类ID " prop="tagcategoryid">
        <el-input
          v-model="queryParams.tagcategoryid"
          placeholder="请输入 标签分类ID "
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label=" 标签名称 " prop="tagname">
        <el-input
          v-model="queryParams.tagname"
          placeholder="请输入 标签名称 "
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label=" 机构ID " prop="orgid">
        <el-input
          v-model="queryParams.orgid"
          placeholder="请输入 机构ID "
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label=" 上传标记 " prop="isupload">
        <el-input
          v-model="queryParams.isupload"
          placeholder="请输入 上传标记 "
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label=" 上传时间 " prop="uploadTime">
        <el-date-picker
          clearable
          v-model="queryParams.uploadTime"
          type="date"
          value-format="yyyy-MM-dd"
          placeholder="请选择 上传时间 "
        >
        </el-date-picker>
      </el-form-item>
      <el-form-item label=" 是否开启 " prop="isenable">
        <el-input
          v-model="queryParams.isenable"
          placeholder="请输入 是否开启 "
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button
          type="primary"
          icon="el-icon-search"
          size="mini"
          @click="handleQuery"
          >搜索</el-button
        >
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery"
          >重置</el-button
        >
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['system:tag:add']"
          >新增</el-button
        >
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['system:tag:edit']"
          >修改</el-button
        >
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['system:tag:remove']"
          >删除</el-button
        >
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
          v-hasPermi="['system:tag:export']"
          >导出</el-button
        >
      </el-col>
      <right-toolbar
        :showSearch.sync="showSearch"
        @queryTable="getList"
      ></right-toolbar>
    </el-row>

    <el-table
      v-loading="loading"
      :data="tagList"
      @selection-change="handleSelectionChange"
    >
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label=" 自增ID " align="center" prop="tagid" />
      <el-table-column
        label=" 标签分类ID "
        align="center"
        prop="tagcategoryid"
      />
      <el-table-column label=" 标签名称 " align="center" prop="tagname" />
      <el-table-column
        label=" 标签描述 "
        align="center"
        prop="tagdescription"
      />
      <el-table-column label=" 机构ID " align="center" prop="orgid" />
      <el-table-column label=" 上传标记 " align="center" prop="isupload" />
      <el-table-column
        label=" 上传时间 "
        align="center"
        prop="uploadTime"
        width="180"
      >
        <template slot-scope="scope">
          <span>{{ parseTime(scope.row.uploadTime, "{y}-{m}-{d}") }}</span>
        </template>
      </el-table-column>
      <el-table-column label=" 是否开启 " align="center" prop="isenable" />
      <el-table-column
        label="操作"
        align="center"
        class-name="small-padding fixed-width"
      >
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['system:tag:edit']"
            >修改</el-button
          >
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['system:tag:remove']"
            >删除</el-button
          >
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total > 0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改标签对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label=" 标签分类ID " prop="tagcategoryid">
          <el-input
            v-model="form.tagcategoryid"
            placeholder="请输入 标签分类ID "
          />
        </el-form-item>
        <el-form-item label=" 标签名称 " prop="tagname">
          <el-input v-model="form.tagname" placeholder="请输入 标签名称 " />
        </el-form-item>
        <el-form-item label=" 标签描述 " prop="tagdescription">
          <el-input
            v-model="form.tagdescription"
            type="textarea"
            placeholder="请输入内容"
          />
        </el-form-item>
        <el-form-item label=" 机构ID " prop="orgid">
          <el-input v-model="form.orgid" placeholder="请输入 机构ID " />
        </el-form-item>
        <el-form-item label=" 删除标记 " prop="delFlag">
          <el-input v-model="form.delFlag" placeholder="请输入 删除标记 " />
        </el-form-item>
        <el-form-item label=" 上传标记 " prop="isupload">
          <el-input v-model="form.isupload" placeholder="请输入 上传标记 " />
        </el-form-item>
        <el-form-item label=" 上传时间 " prop="uploadTime">
          <el-date-picker
            clearable
            v-model="form.uploadTime"
            type="date"
            value-format="yyyy-MM-dd"
            placeholder="请选择 上传时间 "
          >
          </el-date-picker>
        </el-form-item>
        <el-form-item label=" 是否开启 " prop="isenable">
          <el-input v-model="form.isenable" placeholder="请输入 是否开启 " />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listTag, getTag, delTag, addTag, updateTag } from "@/api/system/tag";

export default {
  name: "Tag",
  data() {
    return {
      // 遮罩层
      loading: false,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 标签表格数据
      tagList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        tagcategoryid: null,
        tagname: null,
        tagdescription: null,
        orgid: null,
        isupload: null,
        uploadTime: null,
        isenable: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        delFlag: [
          { required: true, message: " 删除标记 不能为空", trigger: "blur" },
        ],
        isupload: [
          { required: true, message: " 上传标记 不能为空", trigger: "blur" },
        ],
      },
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询标签列表 */
    getList() {
    //   this.loading = true;
    //   listTag(this.queryParams).then((response) => {
    //     this.tagList = response.rows;
    //     this.total = response.total;
    //     this.loading = false;
    //   });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        tagid: null,
        tagcategoryid: null,
        tagname: null,
        tagdescription: null,
        orgid: null,
        delFlag: null,
        updateBy: null,
        updateTime: null,
        createBy: null,
        createTime: null,
        isupload: null,
        uploadTime: null,
        isenable: null,
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map((item) => item.tagid);
      this.single = selection.length !== 1;
      this.multiple = !selection.length;
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加标签";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const tagid = row.tagid || this.ids;
    //   getTag(tagid).then((response) => {
    //     this.form = response.data;
    //     this.open = true;
    //     this.title = "修改标签";
    //   });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate((valid) => {
        if (valid) {
          if (this.form.tagid != null) {
            // updateTag(this.form).then((response) => {
            //   this.$modal.msgSuccess("修改成功");
            //   this.open = false;
            //   this.getList();
            // });
          } else {
            // addTag(this.form).then((response) => {
            //   this.$modal.msgSuccess("新增成功");
            //   this.open = false;
            //   this.getList();
            // });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const tagids = row.tagid || this.ids;
      this.$modal
        .confirm('是否确认删除标签编号为"' + tagids + '"的数据项？')
        .then(function () {
        //   return delTag(tagids);
        })
        .then(() => {
          this.getList();
          this.$modal.msgSuccess("删除成功");
        })
        .catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download(
        "system/tag/export",
        {
          ...this.queryParams,
        },
        `tag_${new Date().getTime()}.xlsx`
      );
    },
  },
};
</script>
